@@ -1,11 +1,9 @@
 package Pcore::DBD::Builder::Pg;
 
-use Pcore qw[-class];
+use Pcore -class;
 
 extends qw[Pcore::DBD::Builder];
 
-no Pcore;
-
 1;
 __END__
 =pod
